@@ -33,6 +33,10 @@ from chatbees.server_models.doc_api import (
     PageStats,
     IndexCrawlRequest,
     DeleteCrawlRequest,
+    OutlineFAQRequest,
+    OutlineFAQResponse,
+    TranscribeAudioRequest,
+    TranscribeAudioResponse,
 )
 from chatbees.server_models.collection_api import (
     ChatAttributes,
@@ -157,6 +161,43 @@ class Collection(BaseModel):
         resp = SummaryResponse.model_validate(resp.json())
         return resp.summary
 
+    def get_document_outline_faq(self, doc_name: str) -> OutlineFAQResponse:
+        """
+        Returns the Outlines and FAQs of the document.
+
+        :param doc_name: the document
+        :return: The Outlines and FAQs of the document
+        """
+        url = f'{Config.get_base_url()}/docs/get_outline_faq'
+        req = OutlineFAQRequest(
+            namespace_name=Config.namespace,
+            collection_name=self.name,
+            doc_name=doc_name,
+        )
+        resp = Config.post(url=url, data=req.model_dump_json())
+        return OutlineFAQResponse.model_validate(resp.json())
+
+    def transcribe_audio(self, fpath: str, lang: str) -> TranscribeAudioResponse:
+        """
+        Transcribe the audio file. This is an expirement API. Please contact us
+        build@chatbees.ai, if you want to try it.
+
+        :param fpath: Local file path of the audio file
+        :param lang: the language of the audio file
+        :return:
+        """
+        url = f'{Config.get_base_url()}/docs/transcribe_audio'
+        req = TranscribeAudioRequest(namespace_name=Config.namespace,
+                                     collection_name=self.name, lang=lang)
+        # Handle tilde "~/blah"
+        fpath = os.path.expanduser(fpath)
+        validate_file(fpath)
+        with open(fpath, 'rb') as f:
+            fname = os.path.basename(fpath)
+            resp = Config.post(url=url, files={'file': (fname, f)},
+                               data={'request': req.model_dump_json()})
+            return TranscribeAudioResponse.model_validate(resp.json())
+
     def ask(
         self, question: str, top_k: int = 5, doc_name: str = None,
     ) -> AskResponse:
